@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002, 2003 Zope Foundation and Contributors.
+# Copyright (c) 2002, 2003, 2018 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -153,11 +153,8 @@ class BaseLoader(AbstractBaseClass):
         actual load, and returns whatever that method returns.
         """
         url = self.normalizeURL(url)
-        r = self.openResource(url)
-        try:
+        with self.openResource(url) as r:
             return self.loadResource(r)
-        finally:
-            r.close()
 
     def loadFile(self, file, url=None):
         """Load from an open file object, *file*.
@@ -172,11 +169,8 @@ class BaseLoader(AbstractBaseClass):
         """
         if not url:
             url = _url_from_file(file)
-        r = self.createResource(file, url)
-        try:
+        with self.createResource(file, url) as r:
             return self.loadResource(r)
-        finally:
-            r.close()
 
     # utilities
 
@@ -214,7 +208,7 @@ class BaseLoader(AbstractBaseClass):
             except urllib2.URLError as e:
                 # urllib2.URLError has a particularly hostile str(), so we
                 # generally don't want to pass it along to the user.
-                self._raise_open_error(url, e.reason) # pragma: no cover
+                self._raise_open_error(url, e.reason)  # pragma: no cover
             except (IOError, OSError) as e:
                 # Python 2.1 raises a different error from Python 2.2+,
                 # so we catch both to make sure we detect the situation.
@@ -371,7 +365,7 @@ class SchemaLoader(BaseLoader):
 
     def schemaComponentSource(self, package, filename):
         parts = package.split(".")
-        if not parts: # pragma: no cover. can we even get here?
+        if not parts:  # pragma: no cover
             raise ZConfig.SchemaError(
                 "illegal schema component name: " + repr(package))
         if "" in parts:
@@ -401,8 +395,8 @@ class ConfigLoader(BaseLoader):
     conform to the schema *schema*.  The ``load*()`` methods
     return a tuple consisting of the configuration object and a
     composite handler.
-    """
 
+    """
 
     def __init__(self, schema):
         if schema.isabstract():
@@ -446,20 +440,14 @@ class ConfigLoader(BaseLoader):
         url = self._loader.schemaComponentSource(pkgname, '')
         if schema.hasComponent(url):
             return
-        resource = self.openResource(url)
         schema.addComponent(url)
-        try:
+        with self.openResource(url) as resource:
             ZConfig.schema.parseComponent(resource, self._loader, schema)
-        finally:
-            resource.close()
 
     def includeConfiguration(self, section, url, defines):
         url = self.normalizeURL(url)
-        r = self.openResource(url)
-        try:
+        with self.openResource(url) as r:
             self._parse_resource(section, r, defines)
-        finally:
-            r.close()
 
     # internal helper
 
@@ -507,7 +495,8 @@ class Resource(object):
     store the constructor arguments. These objects also have a
     :meth:`close` method which will call :meth:`~file.close` on
     *file*, then set the :attr:`file` attribute to ``None`` and the
-    :attr:`closed` attribute to ``True``.
+    :attr:`closed` attribute to ``True``. Using this object as a
+    context manager also closes the file.
 
     All other attributes are delegated to *file*.
     """
@@ -526,3 +515,9 @@ class Resource(object):
 
     def __getattr__(self, name):
         return getattr(self.file, name)
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, t, v, tb):
+        self.close()
